@@ -336,11 +336,11 @@ Expire-Date: 0
             cmd + ' should have failed: ' + stderr)
         if option == '--list-options' and 'qubes' in prog:
              self.assertEquals(stderr,
-                 "qubes-gpg-client: Unknown list option '--garbage-1'\n")
+                 "qubes-gpg-client: Unknown list option --garbage-1\n")
              return True
         if option == '--verify-options' and 'qubes' in prog:
              self.assertEquals(stderr,
-                 "qubes-gpg-client: Unknown verify option '--garbage-1'\n")
+                 "qubes-gpg-client: Unknown verify option --garbage-1\n")
              return True
         for message_fmt in message_fmts:
             if message_fmt.format('--garbage-1') in stderr:
